import QtQuick 1.0

import "BGApi.js" as BGApi

ListView
{
    anchors.margins: 1
    currentIndex:-1
    id:listview
    boundsBehavior:Flickable.StopAtBounds
    model: ListModel {}
    property string selected_bssid
    delegate: epDelegate
    //highlight: Rectangle { color: "lightsteelblue"; radius: 5 }
    focus: true
    clip:true

    ScrollBar {
        id: verticalScrollBar
        y:1
        width: 12; height: listview.height
        anchors.right: listview.right
        orientation: Qt.Vertical
        position: listview.visibleArea.yPosition
        pageSize: listview.visibleArea.heightRatio
    }
    Component
    {
        id: epDelegate
        Item
        {
            id:epoint
            width: parent.width-verticalScrollBar.width; height: 40
            property real detailsOpacity : 0
            Rectangle
            {
                id:background
                anchors.margins:1
                anchors.rightMargin: 2
                anchors.bottomMargin: 2
                anchors.fill:parent
                border.width: 1
                radius: 4
                smooth: true
                clip:true
                color:selected_color()

                function selected_color()
                {
                    if(active)return bg_color.blue2
                    return "transparent"
                }
                MouseArea
                {
                    anchors.fill:parent
                    onClicked:
                    {

                        if(epoint.state=="")
                        {
                            epoint.state = "Details";
                        }else
                        {
                            epoint.state = ""
                        }
                    }

                }
                Loader{
                    id:epointLoader
                    anchors.fill: parent
                    anchors.margins: 2
                    anchors.leftMargin: 4
                    anchors.rightMargin: 4
                    sourceComponent: background.delegate(type)
                }
                Button
                {
                    id: close_button
                    anchors.right:parent.right
                    anchors.bottom:parent.bottom
                    text:"Close"
                    opacity: epoint.detailsOpacity*(type===BGApi.ep_free?0:1)
                    function clicked()
                    {
                        endpoint.cmd_close(index)
                    }
                }

                function delegate(type)
                {
                    if(type===BGApi.ep_tcp)return tcpDelegate
                    if(type===BGApi.ep_tcp_server)return  tcpServerDelegate
                    if(type===BGApi.ep_udp)return tcpDelegate
                    if(type===BGApi.ep_udp_server)return tcpServerDelegate
                    if(type===BGApi.ep_uart)return commonDelegate
                    return defaultDelegate
                }
                Component
                {
                    id: details
                    Rectangle
                    {

                    }
                }
                Component
                {
                    id: commonDelegate
                    Column
                    {
                        spacing:1
                        Text { id:text_index ;text: '<b>'+index+': '+BGApi.ep_name(type)+'</b>'}
                        Row{
                            spacing:10
                            Text { text: active>0?"<b>active</b>":""}
                            Text { text: streaming>0?"<b>streaming to </b>"+destination:""}
                        }
                        Row{
                            spacing:2
                            opacity:epoint.detailsOpacity

                            Button
                            {
                                id:routingCheck
                                anchors.verticalCenter: parent.verticalCenter
                                property bool stream:streaming>0?true:false
                                //height:editRoute.height
                                text:  stream?"streaming":"API"
                                button_color: stream?bg_color.button_color_on:bg_color.button_color_off
                                light_color: stream?bg_color.light_color_on:bg_color.light_color_off
                                text_color: stream?bg_color.text_color_on:bg_color.text_color_off

                                function clicked()
                                {
                                    stream^=1
                                    endpoint.qml_cmd_set_streaming (index,routingCheck.stream)

                                }
                            }
                            Text
                            {
                                anchors.verticalCenter: parent.verticalCenter
                                text: "<b>to</b>"
                                opacity:routingCheck.stream?1:0
                            }
                            FramedTextInput
                            {
                                anchors.verticalCenter: parent.verticalCenter
                                id:editRoute
                                width:50
                                validator: IntValidator{bottom: BGApi.ep_min; top: BGApi.ep_max}
                                text:destination
                                opacity:routingCheck.stream?1:0

                                onAccepted:
                                {
                                    endpoint.qml_cmd_set_streaming_destination (index,editRoute.text);
                                }
                            }

                        }
                    }
                }
                Component
                {
                    id: defaultDelegate
                    Text { id:text_index ;text: '<b>'+index+': '+BGApi.ep_name(type)+'</b>'}
                }

                Component
                {
                    id: tcpServerDelegate
                    Column{
                        Loader{sourceComponent: commonDelegate}

                        Text { text:"<b>local port</b>: "+local_port; opacity:epoint.detailsOpacity}
                     }

                }
                Component
                {
                    id: tcpDelegate
                    Column{
                        Loader{sourceComponent: commonDelegate}

                        Text { text:"<b>local IP</b>: "+BGApi.int_to_ipaddress(local_ip); opacity:epoint.detailsOpacity}
                        Text { text:"<b>local port</b>: "+local_port; opacity:epoint.detailsOpacity}
                        Text { text:"<b>remote IP</b>: "+BGApi.int_to_ipaddress(remote_ip); opacity:epoint.detailsOpacity}
                        Text { text:"<b>remote port</b>: "+remote_port; opacity:epoint.detailsOpacity}
                    }

                }







            }
            states: State {
                name: "Details"
                PropertyChanges { target: epoint; height: 150 }
                PropertyChanges { target: epoint; detailsOpacity: 1 }
            }
            transitions: Transition {
                NumberAnimation { properties: "height"; duration: 300 }
                NumberAnimation { properties: "detailsOpacity"; duration: 300 }
            }

        }

    }
    Connections
    {
        target: system

        onEvt_boot:
        {
            listview.model.clear()
        }
    }
    Connections {
        target: endpoint


        onQml_evt_status:// (int epoint,int type,int streaming,int destination,int active)
        {
            var ep=listview.model.get(endpoint)
            if(!ep)
            {
                ep={"local_ip":0,"local_port":0,"remote_ip":0,"remote_port":0}
            }

            ep["index"]=endpoint
            ep["type"]=type
            ep["active"]=active
            ep["destination"]=destination
            ep["streaming"]=streaming

            listview.model.set(endpoint,ep)

        }
    }
    Connections {
        target: tcpip

        onQml_evt_endpoint_status:// (int epoint,int local_ip,int local_port,int remote_ip,int remote_port)
        {
            var ep=listview.model.get(endpoint)
            if(!ep)
            {
                ep={"index":endpoint,"type":0,"active":false,"destination":-1,"streaming":false}
            }

            ep["local_ip"]=local_ip
            ep["local_port"]=local_port
            ep["remote_ip"]=remote_ip
            ep["remote_port"]=remote_port
            listview.model.set(endpoint,ep)
        }
    }
}
