import QtQuick 1.0
import "BGApi.js" as BGApi
import "ScanListSort.js" as ScanListSort
Item
{
    anchors.fill: parent

    Grid
    {
        id:maingrid
        rows:3
        columns:2
        spacing:2
        anchors.centerIn: parent
        Row
        {
            spacing:2


            AnimButton
            {
                id:power_button
                text:"Turn Wi-Fi on"
                text_off: "Turn Wi-Fi on"
                text_on: "Turn Wi-Fi off"
                text_wait: "Wait..."
                text_color: "black"

                function clicked()
                {
                    if(power_button.state=="off")
                    {
                        sme.cmd_wifi_on()
                    }else
                    {
                        sme.cmd_wifi_off()
                    }
                }
                Connections
                {
                    target: sme

                    onQml_evt_wifi_is_on:
                    {
                        power_button.state="on"
                    }
                    onQml_evt_wifi_is_off:
                    {
                        power_button.state="off"
                    }
                    onQml_rsp_wifi_on:
                    {
                        if(result==0)
                            power_button.state="wait"
                        else
                            power_button.state="off"
                    }
                    onQml_rsp_wifi_off:
                    {
                         power_button.state="off"
                    }
                }
            }
        }
        Row{
            AnimButton
            {
                id: scan_button
                text:"Scan"
                text_off:"Start scan"
                text_on:""
                text_wait:"Stop scan"

                function clicked()
                {
                    if(main.scanning==false)
                    {
                        sme.cmd_start_scan(0,[])
                    }else
                    {
                        sme.cmd_stop_scan()
                    }
                }
                Connections
                {
                    target: sme
                    onEvt_scanned:
                    {
                        scan_button.state="off"
                    }
                    onRsp_start_scan:
                    {
                        if(result==0)
                            scan_button.state="wait"
                        else
                            scan_button.state="off"
                    }
                }
            }
        }
        Column
        {
            id: column1
            spacing:2
            Text
            {
                id: mac_label
                text:"MAC-Address"
            }
            FramedTextInput
            {
                id:macAddress
                y: 0
                inputMask:"HH:HH:HH:HH:HH:HH; "
                width:150
                text:BGApi.beautify_mac(main.mac_address)

                onAccepted:
                {
                   config.qml_cmd_set_mac(0,BGApi.parse_mac(macAddress.text))
                    macAddress.input.focus=false
                }
            }


            Rectangle {
                id: spacer1
                width: 200
                height: 14
                color: "#00000000"
            }

            Button
            {
                id:dhcp
                //anchors.verticalCenter: parent.verticalCenter
                property bool usedhcp:false
                y: 57
                //height:editRoute.height
                text: dhcp.usedhcp?"Disable DHCP":"Enable DHCP"
                anchors.left: parent.left
                anchors.leftMargin: 0

                function clicked()
                {
                    tcpip.qml_cmd_configure (BGApi.ip_to_number(addressIP.text),
                                             BGApi.ip_to_number(netmaskIP.text),
                                             BGApi.ip_to_number(gatewayIP.text),
                                             usedhcp^1);
                }
            }

            Text
            {
                x: 0
                y: 45
                width: 80
                text:dhcp.usedhcp?"DHCP enabled":"Using static IP"
                font.pointSize: 10
                verticalAlignment: Text.AlignVCenter
            }

            Rectangle {
                id: spacer2
                x: 0
                y: -59
                width: 200
                height: 10
                color: "#00000000"
            }

            Text
            {
                id: ipaddr_label
                text:"IP-Address"
            }

            FramedTextInput
            {
                id:addressIP
                inputMask:"000.000.000.000"
                width:parent.width

            }

            Text
            {
                id: netmask_label
                text:"Netmask"
            }


            FramedTextInput
            {
                id:netmaskIP
                inputMask:"000.000.000.000; "
                width:parent.width
            }

            Text
            {
                id: gateway_label
                text:"Gateway"
            }


            FramedTextInput
            {
                id:gatewayIP
                inputMask:"000.000.000.000; "
                width:parent.width
            }

            Connections
            {
                target: sme

                onQml_evt_interface_status:
                {
                     if(status==0)
                     {
                         interface_status.text="No network"
                     }else
                     {
                         interface_status.text="Network ready"
                     }
                }
            }

            Text
            {
                id: dns0_label
                text:"DNS 0"
            }


            FramedTextInput
            {
                id:dns0
                inputMask:"000.000.000.000; "
                width:parent.width
                onAccepted:
                {
                   tcpip.qml_cmd_dns_configure(0,BGApi.ip_to_number(dns0.text))
                    dns0.input.focus=false
                }
            }

            Text
            {
                id: dns1_label
                text:"DNS 1"
            }


            FramedTextInput
            {
                id:dns1
                inputMask:"000.000.000.000; "
                width:parent.width
                onAccepted:
                {
                   tcpip.qml_cmd_dns_configure(1,BGApi.ip_to_number(dns1.text))
                    dns1.input.focus=false
                }
            }

            Text {
                id: interface_status
                height: 33
                text: "No network"
                verticalAlignment: Text.AlignVCenter
                anchors.horizontalCenter: parent.horizontalCenter
                font.bold: true
                font.pointSize: 12
            }


            Connections
            {
                target: tcpip


                onQml_evt_configuration:
                {
                    addressIP.text=BGApi.int_to_ipaddress(address)
                    netmaskIP.text=BGApi.int_to_ipaddress(netmask)
                    gatewayIP.text=BGApi.int_to_ipaddress(gateway)
                    dhcp.usedhcp=use_dhcp
                }
                onQml_evt_dns_configuration:
                {
                    if(index==0)
                    {
                        dns0.text=BGApi.int_to_ipaddress(address)
                    }else
                    {
                        dns1.text=BGApi.int_to_ipaddress(address)
                    }
                }
            }





        }
        BackgroundRectangle
        {
            width:240; height:400



            ScanListView
            {
                id:listview
                anchors.fill:parent
            }

        }
    }
}
