import QtQuick 1.0
Column
{
    id:portselect
    property int major: 0
    property int minor: 0
    property int patch: 0
    property int build: 0
    property int bootloader: 0
    property int tcpip: 0
    property int hw: 0


    anchors.centerIn: parent
    spacing:1
    Row
    {
        id:row1
        spacing:1

    Column
    {
        spacing:1

        Text {
            id: text1
            y: 350
            text: qsTr("Available serial ports")
            font.pixelSize: 12
        }

        Rectangle
        {
            id:portrect
            width:240; height:400
            border.width: 1
            radius: 4
            z: -100
            smooth: true

            gradient: Gradient {
                GradientStop {
                    position: 0.0
                    color: bg_color.light_gradient1
                }
                GradientStop {
                    position: 1.0
                    color: bg_color.light_gradient2
                }
            }

            StaticListView
            {
                id:portlist
                anchors.margins: 1
            }
        }

    }
    Column
    {
        spacing:1


        Text {
            id: baudrate_label
            text: qsTr("Baud rate")
            font.pixelSize: 12
        }

        Rectangle
        {
            id: baudrect
            width:100; height:400
            border.width: 1
            radius: 4
            z: -100
            smooth: true
            gradient: Gradient {
                GradientStop {
                    position: 0.0
                    color: bg_color.light_gradient1
                }
                GradientStop {
                    position: 1.0
                    color: bg_color.light_gradient2
                }
            }


            StaticListView
            {
                id:baudlist
                anchors.margins: 1
            }
        }

    }

    Column
    {
        Rectangle {
            id: spacer
            width: 10
            height: baudrate_label.height
            color: "#00000000"
        }

        Button
        {
            id: attach_button
            text:main.attached?"Detach":"Attach";
            function clicked()
            {
                if(!main.attached)
                    mainobj.open_port(portlist.item().name,portlist.item().port,baudlist.item().baud)
                else
                    mainobj.close_port()

            }
            opacity: 0
            Behavior on opacity {
                NumberAnimation { properties:"opacity"; duration: 200 }
            }
        }


        Button
        {
            id: refresh_button
            text:"Refresh"
            function clicked()
            {
                portlist.model.clear()
                mainobj.refresh_ports()
            }

        }

    }
    }
    Column
    {
        spacing:1

        Text {
            id: text2
            y: 350
            text: qsTr("Device info")
            font.pixelSize: 12
        }

        Rectangle
        {
            width:portrect.width+baudrect.width+1
            height:20
            border.width: 1
            radius: 4
            z: -100
            smooth: true

            gradient: Gradient {
                GradientStop {
                    position: 0.0
                    color: bg_color.light_gradient1
                }
                GradientStop {
                    position: 1.0
                    color: bg_color.light_gradient2
                }
            }
            Row
            {
                anchors.fill: parent
                anchors.margins: 3
                spacing:5
                Text
                {
                    text:"Major:"+major.toString(16)
                }
                Text
                {
                    text:"Minor:"+minor.toString(16)
                }
                Text
                {
                    text:"Patch:"+patch.toString(16)
                }
                Text
                {
                    text:"Build:"+build.toString(16)
                }
                Text
                {
                    text:"Bootloader:"+bootloader.toString(16)
                }
                Text
                {
                    text:"TCP/IP:"+tcpip.toString(16)
                }
                Text
                {
                    text:"HW:"+hw.toString(16)
                }
                }


        }

    }

    Connections {
        target: main
        onDevice_found:
        {
            portlist.model.append({"name":name, "port":port})

        }
        onBaud_rate:
        {
            baudlist.model.append({"name":name, "baud":baud})
        }
        onSelect_baud_rate:
        {
            for (var i=0;i<baudlist.model.count;i++)
            {
                if(baudlist.model.get(i).baud==baud)
                {
                    baudlist.selected(i)
                    baudlist.currentIndex = i;
                }
            }
        }

    }


    Connections
    {
        target: portlist
        onSelected:
        {
            attach_button.opacity=1
        }
    }
    Connections
    {
        target: system

        onEvt_boot:
        {
            portselect.major=major
            portselect.minor=minor
            portselect.patch=patch
            portselect.build=build
            portselect.bootloader=bootloader_version
            portselect.tcpip=tcpip_version
            portselect.hw=hw
        }
    }


}
