import QtQuick 1.0
import "ScanListSort.js" as ScanListSort
import "BGApi.js" as BGApi

ListView
{
    anchors.margins: 1
    currentIndex:-1
    id:listview
    boundsBehavior:Flickable.StopAtBounds
    model: ListModel {}
    property string selected_bssid
    Component.onCompleted: ScanListSort.init(listview.model);
    delegate: scanDelegate
    //highlight: Rectangle { color: "lightsteelblue"; radius: 5 }
    focus: true
    clip:true

    ScrollBar {
        id: verticalScrollBar
        y:1
        width: 12; height: listview.height
        anchors.right: listview.right
        orientation: Qt.Vertical
        position: listview.visibleArea.yPosition
        pageSize: listview.visibleArea.heightRatio
    }
    Component
    {
        id: scanDelegate
        Item
        {
            id:scan
            width: parent.width-verticalScrollBar.width; height: 40
            property real detailsOpacity : 0
            Rectangle
            {
                id:background
                anchors.margins:1
                anchors.rightMargin: 2
                anchors.bottomMargin: 2
                anchors.fill:parent
                border.width: 1
                radius: 4
                smooth: true
                clip:true
                color:selected_color()

                function selected_color()
                {
                    if(main.connected_bssid==bssid)return bg_color.blue2
                    return "transparent"
                }

                Column
                {
                    id:details
                    anchors.fill: parent
                    anchors.margins: 2
                    spacing:1
                    Text { text: '<b>SSID:</b> ' + ssid }
                    Text { text: '<b>BSSID:</b> ' + BGApi.beautify_mac(bssid) }
                    Text { text: '<b>Channel:</b> ' + channel; opacity: scan.detailsOpacity}
                    Text { text: '<b>SNR:</b> ' + snr; opacity: scan.detailsOpacity}
                    Text { text: '<b>RSSI:</b> ' + rssi; opacity: scan.detailsOpacity}
                    Text { text: '<b>Secure:</b> ' + secure; opacity: scan.detailsOpacity}
                }
                Image
                {
                    source: "lock.png";
                    anchors.right: rssi_meter_bg.left;
                    anchors.verticalCenter: rssi_meter_bg.verticalCenter;
                    opacity: secure
                }
                Rectangle
                {
                    id:rssi_meter_bg
                    anchors.right:parent.right
                    anchors.top:parent.top
                    anchors.margins:4
                    width:10
                    height:29
                    border.color: "#000000"
                }
                Rectangle
                {
                    id:rssi_meter
                    anchors.left:rssi_meter_bg.left
                    anchors.right:rssi_meter_bg.right
                    anchors.bottom:rssi_meter_bg.bottom
                    anchors.margins:0
                    height:rssi_height()
                    width:rssi_meter_bg.width
                    color:rssi_color()
                    border.color: "#000000"
                    property int rssi_min:-80
                    property int rssi_max:-30
                    property int rssi_delta:rssi_max-rssi_min
                    function rssi_height()
                    {

                        if(rssi>rssi_max)return rssi_meter_bg.height;
                        if(rssi<rssi_min)return 0;
                        var i=(rssi_meter_bg.height)*(rssi-rssi_min)/rssi_delta;
                        return i;
                    }
                    function rssi_color()
                    {
                        if(rssi<rssi_min+rssi_delta/3)return "red"
                        if(rssi<rssi_min+rssi_delta*2/3)return "yellow"
                        return "green"
                    }
                }


                MouseArea
                {
                    anchors.fill:parent
                    onClicked:
                    {
                        if(listview.selected_bssid!=bssid)
                            listview.selected_bssid=bssid
                        else
                            listview.selected_bssid=""
                    }

                }
                Text
                {
                    anchors.left:parent.left
                    anchors.bottom:password.top
                    anchors.margins: 2
                    text:"Password:"
                    opacity: scan.detailsOpacity
                }

                FramedTextInput
                {
                    id: password
                    anchors.left:parent.left
                    anchors.verticalCenter: connect_button.verticalCenter
                    anchors.right:connect_button.left
                    anchors.margins: 2
                    opacity:scan.detailsOpacity

                }

                Button
                {
                    id: connect_button
                    anchors.right:parent.right
                    anchors.bottom:parent.bottom
                    text:"Connect"
                    opacity: scan.detailsOpacity
                    function clicked()
                    {

                        if(state=="")
                        {
                            sme.qml_cmd_set_password (BGApi.string_to_bytearray(password.text));

                            sme.qml_cmd_connect_bssid(bssid);
                        }else
                        {
                            sme.qml_cmd_disconnect();
                        }
                    }
                    states: State {
                        name: "Connected"
                        when: main.connected_bssid==bssid
                        PropertyChanges { target: connect_button; text: "Disconnect"}

                    }
                }
                state: listview.selected_bssid==bssid?"Current":""//initially open if selected already (no animation in sorting)
                states: State {
                    name: "Current"
                    when: listview.selected_bssid==bssid
                    PropertyChanges { target: scan; height: 180 }
                    PropertyChanges { target: scan; detailsOpacity: 1 }
                }
                transitions: Transition {
                    NumberAnimation { properties: "height"; duration: 300 }
                    NumberAnimation { properties: "detailsOpacity"; duration: 300 }
                }
            }

        }

    }
    Connections {
        target: sme
        onQml_evt_scan_result:
        {
            ScanListSort.update({"ssid": BGApi.bytearray_to_string(ssid),
                                      "bssid":bssid,
                                      "channel":channel,
                                      "rssi":rssi,
                                      "snr":snr,
                                      "secure":secure
                                      })
            ScanListSort.sort();
            //console.log("signal emitted : "+bssid+ssid )
        }
        onQml_evt_scan_result_drop:
        {
            if(listview.selected_bssid==bssid)
                listview.selected_bssid="";
            ScanListSort.drop(bssid);
        }

    }
    Connections
    {
        target: system
        onEvt_boot:
        {
            listview.selected_bssid=""
            ScanListSort.clear()
        }
    }
}
