import QtQuick 1.0

Rectangle {
    // width of the tab bar
    property int tabsWidth : 64

    // index of the active tab
    property int tabIndex : 0

    // the model used to build the tabs
    property VisualItemModel tabsModel

    anchors.fill: parent

    // will contain the tab views
    Rectangle {
	id: tabViewContainer
        height: parent.height

        anchors.right: parent.right
        anchors.left: tabBar.right

	// build all the tab views
	Repeater {
	    model: tabsModel
        }
    }

    Component.onCompleted:
    {
	// hide all the tab views
	for(var i = 0; i < tabsModel.children.length; i++)
	{
	    tabsModel.children[i].visible = false;
	}
	// select the default tab index
	tabClicked(tabIndex);
    }

    function tabClicked(index)
    {
	// unselect the currently selected tab
	tabs.children[tabIndex].color = "transparent";

	// hide the currently selected tab view
	tabsModel.children[tabIndex].visible = false;

	// change the current tab index
	tabIndex = index;

	// highlight the new tab
	tabs.children[tabIndex].color = "#30ffffff";

	// show the new tab view
	tabsModel.children[tabIndex].visible = true;
    }

    Component {
	id: tabBarItem

	Rectangle {
            width: tabs.width
            height: tabs.height / tabsModel.count

	    color: "transparent"

	    Image {
		source: tabsModel.children[index].icon
		anchors.horizontalCenter: parent.horizontalCenter
                anchors.left: parent.left
		anchors.topMargin: 4
	    }

	    Text {
		anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
//                anchors.right: parent.right
//		anchors.bottomMargin: 4
		color: "white"
		text: tabsModel.children[index].name
	    }

	    MouseArea {
		anchors.fill: parent
		onClicked: {
		    tabClicked(index);
		}
	    }
	}
    }

    // the tab bar
    Rectangle {
        width: tabsWidth
        height: parent.height

        // take the whole parent height
        anchors.top: parent.top
        anchors.bottom: parent.bottom

        // attach it to the view left
        anchors.left: parent.left

	id: tabBar
        color:bg_color.blue

/*
	gradient: Gradient {
            GradientStop {position: 0.0; color: bg_color.blue}
            GradientStop {position: 1.0; color: bg_color.blue}
	}
*/
	// place all the tabs in a row
        Column {
	    anchors.fill: parent

            id: tabs

	    Repeater {
		model: tabsModel.count

		delegate: tabBarItem
	    }
        }
    }
}
