import Qt 4.7
import QtQuick 1.0

Rectangle
{
    id:main
    property bool attached: false
    property bool wifi_on: false
    property bool wait_wifi_on: false
    property bool scanning: false
    property bool indfu: false    
    property string connected_bssid: ""
    property string mac_address: ""

    Item
    {
        id:bg_color
        property color blue:"#007AC9"
        property color blue2:"#7AB8E1"

        property color white:"#FFFFFF"
        property color black:"#000000"
        property color gray:"#717073"
        property color dark_gradient1:"#007AC9"
        property color dark_gradient2:"#00293D"
        property color light_gradient1:"#F4F7FA"
        property color light_gradient2:"#C8D2E5"
        property color dark_orange: "#E37222"
        property color light_orange: "#E9994A"

        property color text:black

        property color button_color_off: bg_color.light_gradient1
        property color light_color_off: bg_color.light_gradient1
        property color dark_color_off: bg_color.blue
        property color text_color_off: bg_color.black

        property color button_color_on: bg_color.blue
        property color light_color_on: bg_color.dark_gradient1
        property color dark_color_on: bg_color.dark_gradient2
        property color text_color_on: bg_color.white

    }



    anchors.fill:parent
    //width:800; height:600
    VisualItemModel {
        id: tabsModel
        Tab {
            name: "Device"                        
            //icon: "pics/tab0.png"

            PortSelect{id:portselect}

        }
        Tab {
            name: "Network"
            opacity: main.attached


            //icon: "pics/tab1.png"

            NetworkView{id:network_view}
        }
        Tab {
            name: "Data routing"
            opacity: main.attached
            //icon: "pics/tab1.png"

            EndpointView{}
        }/*
        Tab {
            name: "DNS"
            opacity: main.attached
            //icon: "pics/tab2.png"

            DNSView
            {
                id:dns_view
            }
        }*/
        Tab {
            name: "Persistent store"
            opacity: main.attached
            //icon: "pics/tab2.png"

            PSView
            {
                id:ps_view
            }
        }
        Tab {
            name: "Hardware"
            opacity: main.attached
            //icon: "pics/tab2.png"

            HardwareView
            {
                id:hw_view
            }
        }
        Tab {
            name: "Firmware update"
            opacity: main.attached
            //icon: "pics/tab2.png"

            Dfu
            {
                id:dfu_view
            }
        }
    }


    Item
    {
        /*anchors.top:selectedPort.bottom
        anchors.left:parent.left
        anchors.right:parent.right
        anchors.bottom:parent.bottom
        */
        anchors.fill:parent

        TabbedUI {
            tabsWidth: 120
            tabIndex: 0
            tabsModel: tabsModel
            SelectedPort
            {
                id:selectedPort
            }
        }
    }


    signal device_found(string name,string port)
    signal baud_rate(string name,int baud)
    signal attached(bool attached,string port,string baud)
    signal select_baud_rate(int baud)

    signal upload_progress(int bytes,int total,int elapsed)

    Connections
    {
        target: sme

        onQml_evt_disconnected:
        {
            connected_bssid=""
        }
        onQml_evt_connected:
        {
            connected_bssid=bssid
        }

        onQml_evt_scanned:
        {
            main.scanning=false
        }
        onQml_rsp_start_scan:
        {
            if(result==0)
                main.scanning=true
        }
        onQml_evt_wifi_is_on:
        {
            wifi_on=true
            wait_wifi_on=false
        }
        onQml_rsp_wifi_on:
        {
            if(result==0)
            {
                wait_wifi_on=true
            }
        }
    }
    Connections
    {
        target: config

        onQml_evt_mac_address:
        {
            mac_address=mac
        }
    }
    onAttached:
    {
        main.attached=attached
    }


    Connections
    {
        target: system

        onEvt_boot:
        {
            wifi_on=false
            scanning=false
            wait_wifi_on=false
            connected_bssid=""
            main.indfu=false
        }
    }
    Connections
    {
        target: dfu

        onEvt_boot:
        {
            main.indfu=true
        }
    }



    transform: Rotation {
        id: rotation
        origin.x: main.width/2
        origin.y: main.height/2
        axis.x: 0; axis.y: 1; axis.z: 0     // set axis.y to 1 to rotate around y-axis
        angle: 0    // the default angle
    }

    transitions: Transition {
        NumberAnimation { target: rotation; property: "angle"; duration: 500 }
    }

}
